"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GridRowConfigBuilder = void 0;
const gridAreaBuilder_1 = require("./gridAreaBuilder");
class GridRowConfigBuilder {
    parentBuilder;
    label;
    name;
    areas;
    allowed;
    constructor(parentBuilder) {
        this.parentBuilder = parentBuilder;
        this.areas = [];
    }
    withName(name) {
        this.name = name;
        return this;
    }
    withLabel(label) {
        this.label = label;
        return this;
    }
    withAllowed(allowed) {
        this.allowed = allowed;
        return this;
    }
    addArea(areaBuilder) {
        const builder = areaBuilder === null || areaBuilder === undefined ? new gridAreaBuilder_1.GridAreaBuilder(this) : areaBuilder;
        this.areas.push(builder);
        return builder;
    }
    withSimpleArea(gridSize) {
        this.addArea().withGridSize(gridSize).done();
        return this;
    }
    done() {
        return this.parentBuilder;
    }
    build() {
        if (this.allowed) {
            return {
                allowed: this.allowed,
                name: this.name,
                label: this.label || this.name,
                areas: this.areas.map((builder) => {
                    return builder.build();
                }),
            };
        }
        return {
            name: this.name,
            label: this.label || this.name,
            areas: this.areas.map((builder) => {
                return builder.build();
            }),
        };
    }
}
exports.GridRowConfigBuilder = GridRowConfigBuilder;
//# sourceMappingURL=gridRowConfigBuilder.js.map