"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GridRteBuilder = void 0;
const rteToolbarOptionsBuilder_1 = require("./rteToolbarOptionsBuilder");
class GridRteBuilder {
    parentBuilder;
    maxImageSize;
    mode;
    stylesheets;
    toolbarOptionsBuilder;
    dimensions;
    constructor(parentBuilder) {
        this.parentBuilder = parentBuilder;
        this.stylesheets = [];
    }
    withClassicMode() {
        this.mode = 'classic';
        return this;
    }
    withDistractionFreeMode() {
        this.mode = 'distraction-free';
        return this;
    }
    withMaxImageSize(imageSize) {
        this.maxImageSize = imageSize;
        return this;
    }
    withDimensions(width, height) {
        this.dimensions = {
            width: width,
            height: height,
        };
        return this;
    }
    withStylesheet(virtualPath) {
        this.stylesheets.push(virtualPath);
        return this;
    }
    addToolBarOptions(optionsBuilder) {
        const builder = optionsBuilder === null || optionsBuilder === undefined ? new rteToolbarOptionsBuilder_1.RteToolbarOptionsBuilder(this) : optionsBuilder;
        this.toolbarOptionsBuilder = builder;
        return builder;
    }
    done() {
        return this.parentBuilder;
    }
    build() {
        const RTE = {
            maxImageSize: this.maxImageSize || 500,
            mode: this.mode || 'classic',
            stylesheets: this.stylesheets,
            toolbar: this.toolbarOptionsBuilder.build(),
        };
        if (this.dimensions) {
            Object.assign(RTE, { dimensions: this.dimensions });
        }
        return RTE;
    }
}
exports.GridRteBuilder = GridRteBuilder;
//# sourceMappingURL=gridRteBuilder.js.map