"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GridDataTypeBuilder = void 0;
const dataTypeBuilder_1 = require("./dataTypeBuilder");
const models_1 = require("../../models");
const gridBuilders_1 = require("./gridBuilders");
class GridDataTypeBuilder extends dataTypeBuilder_1.DataTypeBuilder {
    gridDataType;
    preValues = [];
    layoutBuilders;
    templateBuilders;
    settingsBuilders;
    styleBuilders;
    rteBuilder;
    columns = 12;
    ignoreUserStartNodes;
    imageUploadFolder;
    constructor(gridDataType = new models_1.GridDataType()) {
        super(gridDataType);
        this.gridDataType = gridDataType;
        this.templateBuilders = [];
        this.layoutBuilders = [];
        this.settingsBuilders = [];
        this.styleBuilders = [];
    }
    withColumns(columns) {
        this.columns = columns;
        return this;
    }
    withIgnoreUserStartNodes(ignore) {
        this.ignoreUserStartNodes = ignore;
        return this;
    }
    withImageUploadFolder(folderPath) {
        this.imageUploadFolder = folderPath;
        return this;
    }
    addRowConfiguration(gridRowConfigBuilder) {
        const builder = gridRowConfigBuilder === null || gridRowConfigBuilder === undefined
            ? new gridBuilders_1.GridRowConfigBuilder(this)
            : gridRowConfigBuilder;
        this.layoutBuilders.push(builder);
        return builder;
    }
    addLayout(templateBuilder) {
        const builder = templateBuilder === null || templateBuilder === undefined ? new gridBuilders_1.GridLayoutBuilder(this) : templateBuilder;
        this.templateBuilders.push(builder);
        return builder;
    }
    addRte(rteBuilder) {
        const builder = rteBuilder === null || rteBuilder === undefined ? new gridBuilders_1.GridRteBuilder(this) : rteBuilder;
        this.rteBuilder = builder;
        return builder;
    }
    addSetting(settingsBuilder) {
        const builder = settingsBuilder === null || settingsBuilder === undefined ? new gridBuilders_1.GridSettingsbuilder(this) : settingsBuilder;
        this.settingsBuilders.push(builder);
        return builder;
    }
    addStyle(styleBuilder) {
        const builder = styleBuilder === null || styleBuilder === undefined ? new gridBuilders_1.GridStylesBuilder(this) : styleBuilder;
        this.styleBuilders.push(builder);
        return builder;
    }
    withDefaultGrid() {
        this.addSetting()
            .withDescription('Set a css class')
            .withKey('class')
            .withLabel('Class')
            .withView('textstring')
            .done();
        this.addRowConfiguration()
            .withLabel('Headline')
            .withName('Headline')
            .addArea()
            .withGridSize(12)
            .withEditor('headline')
            .done();
        this.addRowConfiguration().withName('Article').withLabel('Article').withSimpleArea(4).withSimpleArea(8).done();
        this.addStyle()
            .withDescription('Set a row background')
            .withKey('background-image')
            .withLabel('Set a background image')
            .withModifier('url({0})')
            .withView('imagepicker')
            .done();
        this.addLayout().withName('1 column layout').withSimpleSection(12).done();
        this.addLayout().withName('2 column layout').withSimpleSection(4).withSimpleSection(8).done();
        this.addRte()
            .withMaxImageSize(500)
            .withClassicMode()
            .addToolBarOptions()
            .withSourceCodeEditor()
            .withStyleSelect()
            .withBold()
            .withItalic()
            .withJustifyLeft()
            .withJustifyCenter()
            .withJustifyRight()
            .withBulletList()
            .withNumberedList()
            .withDecreaseIndent()
            .withIncreaseIndent()
            .withInsertLink()
            .withImage()
            .withMacro()
            .withEmbed()
            .done()
            .done();
        return this;
    }
    build() {
        const items = {
            key: 'items',
            value: {
                columns: this.columns || 12,
                config: this.settingsBuilders.map((builder) => {
                    return builder.build();
                }),
                layouts: this.layoutBuilders.map((builder) => {
                    return builder.build();
                }),
                styles: this.styleBuilders.map((builder) => {
                    return builder.build();
                }),
                templates: this.templateBuilders.map((builder) => {
                    return builder.build();
                }),
            },
        };
        this.preValues.push(items);
        // Add RTE
        const rtePrevalue = {
            key: 'rte',
            value: this.rteBuilder.build(),
        };
        this.preValues.push(rtePrevalue);
        this.preValues.push({
            key: 'ignoreUserStartNodes',
            value: this.ignoreUserStartNodes || false,
        });
        // Add Image upload folder
        this.preValues.push({
            key: 'mediaParentId',
            value: this.imageUploadFolder || null,
        });
        this.dataType.addPrevalues(this.preValues);
        return super.build();
    }
}
exports.GridDataTypeBuilder = GridDataTypeBuilder;
//# sourceMappingURL=gridDataTypeBuilder.js.map