"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const faker_1 = require("faker");
const camelize_1 = require("camelize");
const formPickerDocumentTypePropertyBuilder_1 = require("./properties/formPickerDocumentTypePropertyBuilder");
const textBoxDocumentTypePropertyBuilder_1 = require("./properties/textBoxDocumentTypePropertyBuilder");
const dropDownDocumentTypePropertyBuilder_1 = require("./properties/dropDownDocumentTypePropertyBuilder");
const contentPickerTypePropertyBuilder_1 = require("./properties/contentPickerTypePropertyBuilder");
const properties_1 = require("./properties");
const urlPickerTypePropertyBuilder_1 = require("./properties/urlPickerTypePropertyBuilder");
class DocumentTypeGroupBuilder {
    parentBuilder;
    alias;
    name;
    sortOrder;
    id;
    inherited;
    documentTypeGroupPropertyBuilders;
    constructor(parentBuilder) {
        this.parentBuilder = parentBuilder;
        this.sortOrder = 0;
        this.documentTypeGroupPropertyBuilders = [];
    }
    withName(name) {
        this.name = name;
        return this;
    }
    withAlias(alias) {
        this.alias = alias;
        return this;
    }
    addFormPickerProperty() {
        const builder = new formPickerDocumentTypePropertyBuilder_1.FormPickerDocumentTypePropertyBuilder(this);
        this.documentTypeGroupPropertyBuilders.push(builder);
        return builder;
    }
    addTextBoxProperty() {
        const builder = new textBoxDocumentTypePropertyBuilder_1.TextBoxDocumentTypePropertyBuilder(this);
        this.documentTypeGroupPropertyBuilders.push(builder);
        return builder;
    }
    addDropDownProperty() {
        const builder = new dropDownDocumentTypePropertyBuilder_1.DropDownDocumentTypePropertyBuilder(this);
        this.documentTypeGroupPropertyBuilders.push(builder);
        return builder;
    }
    addContentPickerProperty() {
        const builder = new contentPickerTypePropertyBuilder_1.ContentPickerPropertyBuilder(this);
        this.documentTypeGroupPropertyBuilders.push(builder);
        return builder;
    }
    addUrlPickerProperty() {
        const builder = new urlPickerTypePropertyBuilder_1.UrlPickerPropertyBuilder(this);
        this.documentTypeGroupPropertyBuilders.push(builder);
        return builder;
    }
    addRichTextProperty() {
        const builder = new properties_1.RichTextDocumentTypePropertyEditor(this);
        this.documentTypeGroupPropertyBuilders.push(builder);
        return builder;
    }
    addCustomProperty(id) {
        const builder = new properties_1.CustomDocumentTypePropertyBuilder(this, id);
        this.documentTypeGroupPropertyBuilders.push(builder);
        return builder;
    }
    done() {
        return this.parentBuilder;
    }
    getAlias() {
        return this.alias || 'a' + (0, camelize_1.default)(this.name);
    }
    build() {
        const name = this.name || faker_1.default.random.uuid();
        return {
            id: this.id || -1,
            inherited: this.inherited || false,
            name: this.name || name,
            alias: this.getAlias(),
            sortOrder: this.sortOrder || 0,
            properties: this.documentTypeGroupPropertyBuilders.map((builder) => {
                return builder.build();
            }),
        };
    }
}
exports.default = DocumentTypeGroupBuilder;
//# sourceMappingURL=documentTypeGroupBuilder.js.map